=== modified file 'lib/lp/buildmaster/model/builder.py'
--- lib/lp/buildmaster/model/builder.py	2011-12-16 12:12:04 +0000
+++ lib/lp/buildmaster/model/builder.py	2012-01-02 10:42:21 +0000
@@ -498,7 +498,7 @@
 
     # XXX 2010-08-24 Julian bug=623281
     # This should not be a property!  It's masking a complicated query.
-    @cachedproperty
+    @property
     def currentjob(self):
         """See IBuilder"""
         return getUtility(IBuildQueueSet).getByBuilder(self)

=== modified file 'lib/lp/buildmaster/model/buildfarmjob.py'
--- lib/lp/buildmaster/model/buildfarmjob.py	2011-12-16 12:12:04 +0000
+++ lib/lp/buildmaster/model/buildfarmjob.py	2012-01-02 10:42:21 +0000
@@ -100,6 +100,10 @@
         """See `IBuildFarmJobOld`."""
         raise NotImplementedError
 
+    def getByJobs(self, job):
+        """See `IBuildFarmJobOld`."""
+        raise NotImplementedError
+
     def jobStarted(self):
         """See `IBuildFarmJobOld`."""
         pass

=== modified file 'lib/lp/buildmaster/model/buildqueue.py'
--- lib/lp/buildmaster/model/buildqueue.py	2011-12-16 13:40:17 +0000
+++ lib/lp/buildmaster/model/buildqueue.py	2012-01-02 10:42:21 +0000
@@ -58,10 +58,6 @@
     )
 from lp.services.job.interfaces.job import JobStatus
 from lp.services.job.model.job import Job
-from lp.services.propertycache import (
-    cachedproperty,
-    get_property_cache,
-    )
 
 
 def normalize_virtualization(virtualized):
@@ -142,7 +138,7 @@
         """See `IBuildQueue`."""
         return IBuildFarmJobBehavior(self.specific_job)
 
-    @cachedproperty
+    @property
     def specific_job(self):
         """See `IBuildQueue`."""
         specific_class = specific_job_classes()[self.job_type]
@@ -151,7 +147,6 @@
     @staticmethod
     def preloadSpecificJobData(queues):
         key = attrgetter('job_type')
-        specific_jobs_dict = {}
         for job_type, grouped_queues in groupby(queues, key=key):
             specific_class = specific_job_classes()[job_type]
             queue_subset = list(grouped_queues)
@@ -163,12 +158,6 @@
             if len(list(specific_jobs)) == 0:
                 continue
             specific_class.preloadJobsData(specific_jobs)
-            specific_jobs_dict = dict(
-                (specific_job.job, specific_job)
-                    for specific_job in specific_jobs)
-            for queue in queue_subset:
-                cache = get_property_cache(queue)
-                cache.specific_job = specific_jobs_dict[queue.job]
 
     @property
     def date_started(self):

=== modified file 'lib/lp/soyuz/browser/builder.py'
--- lib/lp/soyuz/browser/builder.py	2011-12-16 12:12:04 +0000
+++ lib/lp/soyuz/browser/builder.py	2012-01-02 10:42:21 +0000
@@ -60,7 +60,6 @@
 from lp.buildmaster.model.buildqueue import BuildQueue
 from lp.services.propertycache import (
     cachedproperty,
-    get_property_cache,
     )
 from lp.soyuz.browser.build import (
     BuildNavigationMixin,
@@ -153,17 +152,11 @@
     def builders(self):
         """All active builders"""
         def do_eager_load(builders):
-            # Populate builders' currentjob cachedproperty.
+            # Prefetch the jobs' data.
             queues = IStore(BuildQueue).find(
                 BuildQueue,
                 BuildQueue.builderID.is_in(
                     builder.id for builder in builders))
-            queue_builders = dict(
-                (queue.builderID, queue) for queue in queues)
-            for builder in builders:
-                cache = get_property_cache(builder)
-                cache.currentjob = queue_builders.get(builder.id, None)
-            # Prefetch the jobs' data.
             BuildQueue.preloadSpecificJobData(queues)
 
         return list(DecoratedResultSet(

=== modified file 'lib/lp/soyuz/browser/tests/test_builder.py'
--- lib/lp/soyuz/browser/tests/test_builder.py	2011-12-16 12:12:04 +0000
+++ lib/lp/soyuz/browser/tests/test_builder.py	2012-01-02 10:42:21 +0000
@@ -5,7 +5,7 @@
 
 __metaclass__ = type
 
-from testtools.matchers import Equals
+from testtools.matchers import LessThan
 from zope.component import getUtility
 from zope.security.proxy import removeSecurityProxy
 
@@ -67,6 +67,15 @@
 
     layer = LaunchpadFunctionalLayer
 
+    # XXX rvb: the 3 additional queries per build are the result of the calls
+    # to:
+    # - builder.currentjob
+    # - buildqueue.specific_job
+    # These could be converted into cachedproperty and pre-populated in
+    # bulk but several tests assert that the value returned by these
+    # these properties are up to date.  Since they are not really expensive
+    # to compute I'll leave them as regular properties for now.
+
     def test_builders_binary_package_build_query_count(self):
         def create_build():
             build = self.createBinaryPackageBuild()
@@ -76,7 +85,9 @@
         recorder1, recorder2 = record_two_runs(
             builders_homepage_render, create_build, 2)
 
-        self.assertThat(recorder2, HasQueryCount(Equals(recorder1.count)))
+        self.assertThat(
+            recorder2,
+            HasQueryCount(LessThan(recorder1.count + 3 * 2 + 1)))
 
     def test_builders_recipe_build_query_count(self):
         def create_build():
@@ -87,7 +98,9 @@
         recorder1, recorder2 = record_two_runs(
             builders_homepage_render, create_build, 2)
 
-        self.assertThat(recorder2, HasQueryCount(Equals(recorder1.count)))
+        self.assertThat(
+            recorder2,
+            HasQueryCount(LessThan(recorder1.count + 3 * 2 + 1)))
 
     def test_builders_translation_template_build_query_count(self):
         def create_build():
@@ -104,4 +117,6 @@
         recorder1, recorder2 = record_two_runs(
             builders_homepage_render, create_build, 2)
 
-        self.assertThat(recorder2, HasQueryCount(Equals(recorder1.count)))
+        self.assertThat(
+            recorder2,
+            HasQueryCount(LessThan(recorder1.count + 3 * 2 + 1)))

